@@ -8,9 +8,7 @@ __docformat__ = 'restructuredtext en'
 from functools import partial
 from zipfile import ZipFile
 
-from qt.core import (
-    QAction, QIcon, QKeySequence, QMenu, QObject, QPoint, QTimer, QToolButton,
-)
+from qt.core import QAction, QIcon, QKeySequence, QMenu, QObject, QPoint, QTimer, QToolButton
 
 from calibre import prints
 from calibre.constants import ismacos
@@ -20,7 +18,7 @@ from polyglot.builtins import string_or_bytes
 
 
 def toolbar_widgets_for_action(gui, action):
-    # Search the the toolbars for the widget associated with an action, passing
+    # Search the toolbars for the widget associated with an action, passing
     # them to the caller for further processing
     for x in gui.bars_manager.bars:
         try:
